Digital Trends | Technology News and Product Reviews
Description: Digital Trends is your premier source for technology news and unbiased expert product reviews of TVs, laptops, smartphones and more.

####
If you're looking for the finest
Sony TV ever made, this is it.

DT Review by Caleb Denison

####
Trends with Benefits:
Google Fiber,
touchy feely
tech, and the
return of vinyl

####
Ready to throw
away your keys?
August makes
the best smart
lock on
the market

by Drew Prindle

####
Even your technophobic
loved ones will
appreciate these
easy-to-use
gadgets

####
Apple's garage inception
story is an 'overblown myth,'
says co-founder
Wozniak

by Adrian Diaconescu
Recent Stories
Trending Stories

### CBS pulls the plug on Dish customers in several major cities [Update]

CBS and Dish's negotiations have stalled out, leaving programming like 60 Minutes, Big Bang Theory, and NFL football dark for subscribers in several key markets.

Home Theater
By Christine Persaud — December 5, 2014

### Your say Friday: Will you be going 4K this holiday?

4K monitors have come down in price, but they're still not perfect. Will you be buying one this holiday shopping season?

Computing
By Matt Smith — December 5, 2014

### Want to watch the world flick by at over 200 mph? Hop on the world’s fastest trains

See all 7 images »

### Want to watch the world flick by at over 200 mph? Hop on the world’s fastest trains

See all 7 images »

### If you're looking for the finest Sony TV ever made, this is it.

Product Review
8

The X950B is in a tight run for best LCD television in 2014, thanks to stellar black levels, minimal halo effect, and an all-around gorgeous picture. Beyond that, Sony offers a…

- Pros: Deep black levels , Excellent shadow detail , Top-notch 4K…
- Cons: Color needs adjustment out-of-box , Ugly, shoddy webcam…

By Caleb Denison — December 5, 2014

### Digital Trends Podcast - Episode 8

Do you want Fiber badly enough? Google will be the judge. Meanwhile, Apple is in trouble over digital music, vinyl continues to drive the return of analog music, and "feeling" holograms is finally a reality. Yes, really.

Podcasts
By Digital Trends Staff — December 5, 2014

### Ferrari has delivered its first Pininfarina-designed Sergio. Did the concept look better?

See all 5 images »

### Ferrari has delivered its first Pininfarina-designed Sergio. Did the concept look better?

See all 5 images »

### Apple catches a break: New evidence sends a plaintiff packing in iPod lawsuit

A day after plaintiffs in Apple's antitrust lawsuit revealed Apple removed non-iTunes songs from their iPods between 2007-2009, Apple reveals one of the plaintiffs did not purchase an iPod under the time period, leaving lawyers scrambling for a new witness.

Music
By Keith Nelson Jr. — December 5, 2014

### Crime fighting gets polygonal with the Zijing Qingyuan electric patrol vehicle

The unique looking EV can resist small arms fire and can sport smoke grenade launchers. Making its debut at a Beijing security exhibition, police departments show keen interest.

Cars
By Alexander Kalogianni — December 5, 2014

### Ready to throw away your keys? August makes the best smart lock on the market

Product Review
9

The August Smart Lock easily installs over your existing deadbolt, so you can make any door “smart” and unlockable with only your smartphone.

- Pros: Polished user experience , Easy to install , Excellent…
- Cons: A tad bulky , Android app lacks crucial features (for now)

By Drew Prindle — December 5, 2014

### Decrypt This: Professional-grade encryption for the average person

Staying protected on the web is more important today than ever before. Follow our encryption guide to get yourself and your computer locked down from threats for good.

Computing
By Chris Stobing — December 5, 2014

### Google takes down several Pirate Bay apps, says no to piracy

Whenever Google removes apps from the Play Store, it's usually worth paying attention to. In this case, that's especially true, as four Pirate Bay-related apps were proactively removed.

Mobile
By Williams Pelegrin — December 5, 2014

### Audi rumored to challenge Tesla’s Model X with an all-electric SUV of its own

In the wake of the reveal of Tesla’s electric CUV, Audi CEO hints that development of a competitor is already underway. Rumors speculate that an all-electric powertrain will find itself in the upcoming Q8

Cars
By Alexander Kalogianni — December 5, 2014

### PlayStation 3 Godzilla likely headed stateside after Game Awards reveal

The PlayStation 3 Godzilla game, set for Japanese release on December 18, 2014, is likely heading Stateside sometime thereafter, with a likely reveal at tonight's Game Awards.

Gaming
By Will Fulton — December 5, 2014

### Easter egg game in new 3DS unlocked by Mario theme

Users have discovered a clever little easter egg in the web browser of the new Nintendo 3DS, where tapping the Mario theme unlocks a secret, Breakout-style game.

Gaming
By Will Fulton — December 5, 2014

### The SousVant makes sous vide simple

Newly launched on Kickstarter, the SousVant makes sous vide simple; the machine has a clear, removable carafe and only four buttons. The display shows cooking time and temperature, so it's almost fool-proof.

Home
By Jenny McGrath — December 5, 2014
Older Posts